@@ -108,6 +108,10 @@ sub nth_prime_upper {
   _validate_positive_integer($n);
   return Math::Prime::Util::PP::nth_prime_upper($n);
 }
+sub inverse_li {
+  my($n) = @_;
+  return Math::Prime::Util::PP::inverse_li($n);
+}
 sub nth_prime_approx {
   my($n) = @_;
   _validate_positive_integer($n);
@@ -297,6 +301,16 @@ sub is_quasi_carmichael {
   #_validate_positive_integer($n);
   return Math::Prime::Util::PP::is_quasi_carmichael($n);
 }
+sub is_semiprime {
+  my($n) = @_;
+  _validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_semiprime($n);
+}
+sub is_pillai {
+  my($n) = @_;
+  #_validate_positive_integer($n);
+  return Math::Prime::Util::PP::is_pillai($n);
+}
 sub is_primitive_root {
   my($a,$n) = @_;
   $n = -$n if defined $n && $n < 0;
@@ -773,6 +787,14 @@ sub vecfirst (&@) {     ## no critic qw(ProhibitSubroutinePrototypes)
   undef;
 }
 
+sub vecfirstidx (&@) {     ## no critic qw(ProhibitSubroutinePrototypes)
+  my $sub = shift;
+  { my $pp; local *_ = \$pp; my $i = 0;
+    for my $v (@_) { $pp = $v; return $i if $sub->(); $i++; }
+  }
+  -1;
+}
+
 sub vecextract {
   my($aref, $mask) = @_;
   croak "vecextract first argument must be an array reference"
