@@ -12,7 +12,7 @@ use Math::Prime::Util qw/ prime_get_config
 
 BEGIN {
   $Math::Prime::Util::RandomPrimes::AUTHORITY = 'cpan:DANAJ';
-  $Math::Prime::Util::RandomPrimes::VERSION = '0.59';
+  $Math::Prime::Util::RandomPrimes::VERSION = '0.61';
 }
 
 BEGIN {
@@ -86,8 +86,8 @@ sub _set_randf {
   return if defined $_RANDF;
 
   if (!defined $_IRANDF) {   # Default irand: BRS nonblocking
-    require Bytes::Random::Secure;
-    $_BRS = Bytes::Random::Secure->new(NonBlocking=>1) unless defined $_BRS;
+    require Bytes::Random::Secure::Tiny;
+    $_BRS = Bytes::Random::Secure::Tiny->new(NonBlocking=>1) unless defined $_BRS;
     $_RANDF_NBIT = sub {
       my($bits) = int("$_[0]");
       return 0 if $bits <= 0;
@@ -869,8 +869,8 @@ sub random_shawe_taylor_prime_with_cert {
   my $irandf = prime_get_config->{'irand'};
   if (!defined $irandf) {
     if (!defined $_BRS) {
-      require Bytes::Random::Secure;
-      $_BRS = Bytes::Random::Secure->new(NonBlocking=>1);
+      require Bytes::Random::Secure::Tiny;
+      $_BRS = Bytes::Random::Secure::Tiny->new(NonBlocking=>1);
     }
     $seed = $_BRS->bytes(512/8);
   } else {
@@ -1068,7 +1068,7 @@ sub miller_rabin_random {
   # Testing this many bases is silly, but let's pretend they have some
   # good reason.  A composite n > 9 must have at least n/4 witnesses,
   # hence we need to check only floor(3/4)+1 at most.  We could improve
-  # this is $_Config{'assume_rh'} is true, to 1 .. 2(logn)^2.
+  # this if $_Config{'assume_rh'} is true, to 1 .. 2(logn)^2.
   if ($k >= int(3*$n/4)) {
     return is_strong_pseudoprime($n, 2 .. int(3*$n/4)+1+2 );
   }
@@ -1106,7 +1106,7 @@ Math::Prime::Util::RandomPrimes - Generate random primes
 
 =head1 VERSION
 
-Version 0.59
+Version 0.61
 
 
 =head1 SYNOPSIS
