@@ -4,7 +4,7 @@ use warnings;
 
 BEGIN {
   $ntheory::AUTHORITY = 'cpan:DANAJ';
-  $ntheory::VERSION = '0.59';
+  $ntheory::VERSION = '0.61';
 }
 
 BEGIN {
@@ -92,6 +92,7 @@ See L<Math::Prime::Util> for complete documentation.
   ramanujan_prime_count(start, end)   count of Ramanujan primes in range
   nth_ramanujan_prime(n)              the nth Ramanujan prime (Rn)
   legendre_phi(n,a)                   # below n not div by first a primes
+  inverse_li(n)                       integer inverse logarithmic integral
   prime_precalc(n)                    precalculate primes to n
   sum_primes([start,] end)            return summation of primes in range
   print_primes(start,end[,fd])        print primes to stdout or fd
@@ -146,6 +147,7 @@ See L<Math::Prime::Util> for complete documentation.
   vecnone { ... } @list               return true if none are true
   vecnotall { ... } @list             return true if not all are true
   vecfirst { ... } @list              return first value that evals true
+  vecfirstidx { ... } @list           return first index that evals true
 
 =head2 MATH
 
@@ -163,6 +165,8 @@ See L<Math::Prime::Util> for complete documentation.
   is_carmichael(n)                    is n a Carmichael number
   is_quasi_carmichael(n)              is n a quasi-Carmichael number
   is_primitive_root(r,n)              is r a primitive root mod n
+  is_pillai(n)                        v where  v! % n == n-1  and  n % v != 1
+  is_semiprime(n)                     does n have exactly 2 prime factors
   sqrtint(n)                          integer square root
   rootint(n,k)                        integer k-th root
   rootint(n,k,\$rk)                   as above but also set $rk to r^k
