@@ -57,7 +57,7 @@ extern long double _XS_LogarithmicIntegral(long double x);
 extern long double ld_riemann_zeta(long double x);
 extern long double _XS_RiemannR(long double x);
 extern long double lambertw(long double k);
-extern UV _XS_Inverse_Li(UV x);
+extern UV inverse_li(UV x);
 
 extern int kronecker_uu(UV a, UV b);
 extern int kronecker_su(IV a, UV b);
@@ -81,9 +81,12 @@ extern UV znprimroot(UV n);
 extern UV znorder(UV a, UV n);
 extern int is_primitive_root(UV a, UV n, int nprime);
 #define is_square_free(n)  (moebius(n) != 0)
+extern int is_semiprime(UV n);
 extern int is_carmichael(UV n);
 extern UV  is_quasi_carmichael(UV n);  /* Returns number of bases */
+extern UV  pillai_v(UV n);             /* v: v! % n == n-1 && n % v != 1 */
 
+extern UV stirling3(UV n, UV m);
 extern IV stirling2(UV n, UV m);
 extern IV stirling1(UV n, UV m);
 
